<?php

namespace Ems\Logic\ProcessamentoSolicitacao;

use Ems\Util\Utils;
use Util\{ DateUtil, NovoCodigo, Repositories };

class ProcessamentoSolicitacaoSubstituicao extends ProcessamentoSolicitacao {
    
    public function efetivar() {
        $itens = $this->getItensAssociativeArray();
        
        $nrvinculom          = $itens['NRVINCULOM']   ?? null;
        $nrorg                 = Utils::getParamters()->getNrorg();
        

        if(!$nrvinculom) {
            throw new \Exception("Não foi encontrado nenhum vínculo que irá substituir o vínculo em questão, favor passar primeiro pela rotina de admissão completa informando o Nr. Vínculo: ". $nrvinculom ." no PG.");
        }

        $vinculom = Utils::getEntityManager()->getRepository(Repositories::GPE_VINCULOM)->findOneBy(array('nrorg' => $nrorg, 'nrvinculom' => $nrvinculom));
        $vinculoh = Utils::getEntityManager()->getRepository(Repositories::GPE_VINCULOH)->findOneBy(array('nrorg' => $nrorg, 'nrvinculom' => $nrvinculom));

        if($vinculoh) {
            $dtadmissaovinc = $vinculom->getDtadmissaovinc()->format(DateUtil::FORMATO_BRASILEIRO);
            $dtmescompetenc = (DateUtil::truncateData(DateUtil::getPrimeiroDiaDoMes(DateUtil::getDataDeString($dtadmissaovinc, DateUtil::FORMATO_BRASILEIRO, true))));

            $vinculoh->setDtmescompetenc($dtmescompetenc);
            $vinculoh->setNrorgultatu(Utils::getParamters()->getNrorg());
            $vinculoh->setCdoperultatu(Utils::getParamters()->getCdoperador());
            $vinculoh->setDtultatu(DateUtil::getDataAtual());

            Utils::getEntityManager()->persist($vinculoh);
            Utils::getEntityManager()->flush();
        }
        
    }
    
    public function rejeitar() {
        $itens = $this->getItensAssociativeArray();
        
        $nrvinculom          = $itens['NRVINCULOM']   ?? null;
        $nrorg                 = Utils::getParamters()->getNrorg();


        if(!$nrvinculom) return;

        $vinculom = Utils::getEntityManager()->getRepository(Repositories::GPE_VINCULOM)->findOneBy(array('nrorg' => $nrorg, 'nrvinculom' => $nrvinculom));

        if($vinculom) {

            $this->removeHistoricoVinculo($nrorg, $nrvinculom);

            $vinculom->setDtrescisaovinc($vinculom->getDtadmissaovinc());
            $vinculom->setNrorgultatu(Utils::getParamters()->getNrorg());
            $vinculom->setCdoperultatu(Utils::getParamters()->getCdoperador());
            $vinculom->setDtultatu(DateUtil::getDataAtual());

            Utils::getEntityManager()->persist($vinculom);
            Utils::getEntityManager()->flush();
        }
    }

    public function removeHistoricoVinculo($nrorg, $nrvinculom) {
        $sql = <<<SQL
        DELETE FROM GPE_VINCULOH VH
        WHERE VH.NRORG = :P_NRORG
        AND VH.NRVINCULOM = :P_NRVINCULOM
SQL;

        return Utils::getEntityManager()->getConnection()->prepare($sql)
            ->execute(array(
                "P_NRORG"        => $nrorg,
                "P_NRVINCULOM"   => $nrvinculom
            )
        );
    }

    /*
    public function atualizaVinculoHistorico($nrorg, $nrvinculom, $dtrescisaovinc, $cdoperador) {
        $sql = <<<SQL
        UPDATE GPE_VINCULOM VM
        SET VM.NRORGULTATU = :P_NRORG,
            VM.DTRESCISAOVINC = :P_DTRESCISAOVINC,
            VM.CDOPERULTATU = :P_CDOPERADOR
        WHERE VM.NRORG = :P_NRORG
        AND VM.NRVINCULOM = :P_NRVINCULOM
SQL;

        return Utils::getEntityManager()->getConnection()->prepare($sql)
            ->execute(array(
                "P_NRORG"          => $nrorg,
                "P_NRVINCULOM"     => $nrvinculom,
                "P_DTRESCISAOVINC" => $dtrescisaovinc,
                "P_CDOPERADOR"     => $cdoperador
            )
        );
    }*/

}
