<?php

namespace Ems\Services;

use Util\Environment;
use Ems\Repository\DependenteRepository;
use Util\NovoCodigo;

class DependenteService {
    /** @var DependenteRepository */
    protected $dependenteRepository;

    /** @var Environment */
    protected $environment;

    public function __construct(
        Environment             $environment,
        DependenteRepository    $dependenteRepository
    ) {
        $this->environment = $environment;
        $this->dependenteRepository = $dependenteRepository;
    }

    public function setRelacionaParc(
        array $row
    ): int {
        $nrOrg = (int) $this->environment->getNrOrg();
        $cdOperador = (string) $this->environment->getCdOperador();
        $params = [];

        $params['NRRELACIONAPARC'] =
            $row['NRRELACIONAPARC'] ??
            NovoCodigo::geraCodigo($nrOrg, 'RELACIONAPARC', 1, 12, true, false);

        $params['NRORG']                = $row['NRORG'] ?? $nrOrg;
        $params['NRPARCNEGOCIO']        = (int) $row['NRPARCNEGOCIO'];
        $params['NRPARCNEGRELAC']       = (int) $row['NRPARCNEGRELAC'];
        $params['NRTIPORELACIONA']      = (int) $row['NRTIPORELACIONA'];
        $params['CDCARGO']              = $row['CDCARGO'] ?? null;
        $params['IDATIVO']              = $row['IDATIVO'] ?? 'S';
        $params['DTINCLUSAO']           = $row['DTINCLUSAO'] ?? date('d/m/Y');
        $params['DTULTATU']             = $row['DTULTATU'] ?? null;
        $params['NRORGINCLUSAO']        = $row['NRORGINCLUSAO'] ?? $nrOrg;
        $params['CDOPERINCLUSAO']       = $row['CDOPERINCLUSAO'] ?? $cdOperador;
        $params['NRORGULTATU']          = $row['NRORGULTATU'] ?? null;
        $params['CDOPERULTATU']         = $row['CDOPERULTATU'] ?? null;
        $params['DTFIMRELACIONAMENTO']  = $row['DTFIMRELACIONAMENTO'] ?? null;
        $params['NRPARCTESTE']          = $row['NRPARCTESTE'] ?? null;

        $this->dependenteRepository->setRelacionaParc($params);

        return $params['NRRELACIONAPARC'];
    }

    public function setDepVinculo(
        array $row
    ): int {
        $nrOrg = (int) $this->environment->getNrOrg();
        $params = [];

        $params['NRDEPVINCULO'] =
            $row['NRDEPVINCULO'] ??
            NovoCodigo::geraCodigo($nrOrg, 'FPA_DEPVINCULO', 1, 12, true, false);

        $params['NRORG']            = $nrOrg;
        $params['NRVINCULOM']       = (int) $row['NRVINCULOM'];
        $params['NRPESSOA']         = (int) $row['NRPESSOA'];
        $params['NROUTRVINCULOM']   = $row['NROUTRVINCULOM'] ?? null;
        $params['NRTIPODEPENDE']    = (int) $row['NRTIPODEPENDE'];
        $params['NREVENTOM']        = $row['NREVENTOM'] ?? null;
        $params['DTINIDEPENDE']     = $row['DTINIDEPENDE'] ?? null;
        $params['DTFINDEPENDE']     = $row['DTFINDEPENDE'] ?? null;
        $params['IDDEPENDECONTA']   = $row['IDDEPENDECONTA'] ?? null;
        $params['IDEXCDEPENDE']     = $row['IDEXCDEPENDE'] ?? null;
        $params['IDUNIVERSITARIO']  = $row['IDUNIVERSITARIO'] ?? null;
        $params['NREXCEDEPENDE']    = $row['NREXCEDEPENDE'] ?? null;
        $params['DTINIDEPENDEXC']   = $row['DTINIDEPENDEXC'] ?? null;
        $params['DTFINDEPENDEXC']   = $row['DTFINDEPENDEXC'] ?? null;
        $params['DTVERCONTROLE']    = $row['DTVERCONTROLE'] ?? null;
        $params['DTINCLUSAO']       = $row['DTINCLUSAO'] ?? date('d/m/Y');
        $params['DTULTATU']         = $row['DTULTATU'] ?? null;
        $params['NRORGINCLUSAO']    = $row['NRORGINCLUSAO'] ?? $nrOrg;
        $params['CDOPERINCLUSAO']   = $row['CDOPERINCLUSAO'] ?? 1;
        $params['NRORGULTATU']      = $row['NRORGULTATU'] ?? null;
        $params['CDOPERULTATU']     = $row['CDOPERULTATU'] ?? null;

        $this->dependenteRepository->setDepVinculo($params);

        return $params['NRDEPVINCULO'];
    }
}